Opcode

Enum Opcode 

pub enum Opcode {
    Before(Uuid),
    After(Uuid),
    Push(Uuid, bool),
    And,
    Or,
    Not,
    True,
    False,
    End,
    Sor,
    Unknown,
    Malformed {
        opcode: u8,
        len: usize,
    },
}
A UEFI dependency expression (DEPEX) opcode

Variants



Before(Uuid)

If present, this must be the first and only opcode, may be used by DXE and SMM drivers.



After(Uuid)

If present, this must be the first and only opcode, may be used by DXE and SMM drivers.



Push(Uuid, bool)

A Push opcode is followed by a GUID.



And

A logical AND operation of the two operands on the top of the stack.



Or

A logical OR operation of the two operands on the top of the stack.



Not

A logical NOT operation of the operand on the top of the stack.



True

Pushes a true value onto the stack.



False

Pushes a false value onto the stack.



End

The End opcode is the last opcode in the expression.



Sor

If present, this must be the first opcode in the expression. Used to schedule on request.



Unknown

An unknown opcode. Indicates an unrecognized opcode that should be treated as an error during evaluation.



Malformed

A known opcode with an unexpected payload length.

Fields

opcode: u8

The unhandled opcode value.

len: usize

The length of the payload sent with the opcode.